Learn R Programming

nametagger (version 0.1.7)

europeananews: Tagged news paper articles from Europeana

Description

BIO-tagged news articles in different languages extracted from https://github.com/EuropeanaNewspapers/ner-corpora using europeana_read

  • Dutch from the Koninklijke Bibliotheek

  • Austrian from the National Library of Austria

  • German from the Dr. Friedrich Teßmann Library

  • French from the National Library of France, in cooperation with LIP6-ACASA

Arguments

References

Europeana Newspapers project, (2014), KB Europeana Newspapers NER Dataset. KB Lab: The Hague. https://lab.kb.nl/dataset/europeana-newspapers-ner

Examples

Run this code
data(europeananews)
str(europeananews)

Run the code above in your browser using DataLab